OneTapLocationErrorCode enum

The reason a OneTapLocationException was raised.

Inheritance
Available extensions

Values

locationUnavailable → const OneTapLocationErrorCode

The platform could not determine the position.

On Android, this is also reported when the user allowed only approximate location and Android determined no approximate position within 30 seconds.

locationServicesDisabled → const OneTapLocationErrorCode

Location services are turned off on the device.

Neither iOS nor Android asks the user to turn them on after a tap, so the app can explain that they are needed; the user turns them on in the system settings.

unknown → const OneTapLocationErrorCode

The platform reported an error that no other code describes.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<OneTapLocationErrorCode>
A constant List of the values in this enum, in order of their declaration.