OneTapLocationException class final

An error that prevented a position from being obtained.

Implemented types
Annotations

Constructors

OneTapLocationException(OneTapLocationErrorCode code, [String? message])
Creates an exception with a code and an optional platform message.
const

Properties

code → OneTapLocationErrorCode
The reason for the error.
final
hashCode → int
The hash code for this object.
no setteroverride
message → String?
The description provided by the platform, if any.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override