FakeLocationRequest class final

A request for location access, made by a tap on a OneTapLocationButton that uses a FakeOneTapLocation.

Answer the request as the user and the system would:

Properties

hashCode → int
The hash code for this object.
no setterinherited
isPending → bool
Whether the request waits for an answer.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

complete(OneTapLocationResult result) → void
Reports result and ends the request.
dismiss() → void
Ends the request without a result, and the controller of the button reports OneTapLocationDiagnostic.tapWithoutAuthorization.
grantAccess() → void
Grants access, so that the button starts to determine the position.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited