isPending property
bool
get
isPending
Whether the request waits for an answer.
False once the request is answered, and once the button that made it is removed. Answers to a request of a removed button have no effect.
Implementation
bool get isPending =>
_state == _FakeRequestState.waiting ||
_state == _FakeRequestState.locating;