hasAndroidSystemButton property

bool hasAndroidSystemButton
getter/setter pair

Whether the device has the system location button when the target platform is Android, as devices with Android 17 and later do.

Defaults to false, as on Android 7 to 16. A button reads the value when it is created.

Implementation

bool hasAndroidSystemButton = false;