install static method

FakeOneTapLocation install()

Installs a new fake and returns it, replacing a fake that was installed before.

Buttons keep what they were created with: buttons that exist already keep reaching the platform or the previous fake.

Implementation

static FakeOneTapLocation install() {
  final FakeOneTapLocation fake = FakeOneTapLocation._();
  platformOverride = fake._platform;
  return fake;
}