result property

OneTapLocationResult? result
getter/setter pair

The result that a new request reports once the tap has been handled.

The result is reported with the progress that a device reports before it; see FakeLocationRequest.complete. When null, a request waits until the test answers it.

Implementation

OneTapLocationResult? result;