grantAccess method
void
grantAccess()
Grants access, so that the button starts to determine the position.
OneTapLocationController.isLocating stays true until complete reports the outcome.
Throws a StateError if access was granted already or the request was answered.
Implementation
void grantAccess() {
_checkNotAnswered();
if (_isCancelled) {
return;
}
if (_state == _FakeRequestState.locating) {
throw StateError('Access was granted already for this request.');
}
_state = _FakeRequestState.locating;
_listener.onLocating();
}