uninstall method
void
uninstall()
Removes this fake, so that buttons created afterwards reach the platform again.
Does nothing when another fake has replaced this one.
Implementation
void uninstall() {
if (identical(platformOverride, _platform)) {
platformOverride = null;
}
}